#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-logger
version:              2.5.0
visibility:           public
id:                   wai-logger-2.5.0-BgDOkEjehb27BQJrax94l7
key:                  wai-logger-2.5.0-BgDOkEjehb27BQJrax94l7
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             A logging system for WAI
description:          A logging system for WAI(Web Application Interface)
category:             Web, Yesod
abi:                  37e8bd1823fe93750d8555ba6d788e4a
exposed:              True
exposed-modules:      Network.Wai.Logger
hidden-modules:
    Network.Wai.Logger.Apache Network.Wai.Logger.IP
    Network.Wai.Logger.IORef

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-logger-2.5.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-logger-2.5.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-logger-2.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-logger
hs-libraries:         HSwai-logger-2.5.0-BgDOkEjehb27BQJrax94l7
depends:
    base-4.18.2.1 byteorder-1.0.4-IFlP2E44NdRWUzguGw0c2
    bytestring-0.11.5.3 fast-logger-3.2.4-HL576zACtEy7pAc0R6TdOR
    http-types-0.12.4-G7h7u8FYl0yCakR0583rKK
    network-3.1.4.0-C8IvtFvf3OVKggpOXnCQiO
    wai-3.2.4-7YbaDdPfmbRIZrux7wwPLM

haddock-interfaces:   /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html:         /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

